# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import sys

from google.api_core.protobuf_helpers import get_messages

from google.ads.google_ads.v1.proto.common import ad_asset_pb2
from google.ads.google_ads.v1.proto.common import ad_type_infos_pb2
from google.ads.google_ads.v1.proto.common import asset_types_pb2
from google.ads.google_ads.v1.proto.common import bidding_pb2
from google.ads.google_ads.v1.proto.common import click_location_pb2
from google.ads.google_ads.v1.proto.common import criteria_pb2
from google.ads.google_ads.v1.proto.common import criterion_category_availability_pb2
from google.ads.google_ads.v1.proto.common import custom_parameter_pb2
from google.ads.google_ads.v1.proto.common import dates_pb2
from google.ads.google_ads.v1.proto.common import explorer_auto_optimizer_setting_pb2
from google.ads.google_ads.v1.proto.common import extensions_pb2
from google.ads.google_ads.v1.proto.common import feed_common_pb2
from google.ads.google_ads.v1.proto.common import final_app_url_pb2
from google.ads.google_ads.v1.proto.common import frequency_cap_pb2
from google.ads.google_ads.v1.proto.common import keyword_plan_common_pb2
from google.ads.google_ads.v1.proto.common import matching_function_pb2
from google.ads.google_ads.v1.proto.common import metrics_pb2
from google.ads.google_ads.v1.proto.common import policy_pb2
from google.ads.google_ads.v1.proto.common import real_time_bidding_setting_pb2
from google.ads.google_ads.v1.proto.common import segments_pb2
from google.ads.google_ads.v1.proto.common import simulation_pb2
from google.ads.google_ads.v1.proto.common import tag_snippet_pb2
from google.ads.google_ads.v1.proto.common import targeting_setting_pb2
from google.ads.google_ads.v1.proto.common import text_label_pb2
from google.ads.google_ads.v1.proto.common import url_collection_pb2
from google.ads.google_ads.v1.proto.common import user_lists_pb2
from google.ads.google_ads.v1.proto.common import value_pb2
from google.ads.google_ads.v1.proto.enums import access_reason_pb2
from google.ads.google_ads.v1.proto.enums import account_budget_proposal_status_pb2
from google.ads.google_ads.v1.proto.enums import account_budget_proposal_type_pb2
from google.ads.google_ads.v1.proto.enums import account_budget_status_pb2
from google.ads.google_ads.v1.proto.enums import ad_customizer_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import ad_group_ad_rotation_mode_pb2
from google.ads.google_ads.v1.proto.enums import ad_group_ad_status_pb2
from google.ads.google_ads.v1.proto.enums import ad_group_criterion_approval_status_pb2
from google.ads.google_ads.v1.proto.enums import ad_group_criterion_status_pb2
from google.ads.google_ads.v1.proto.enums import ad_group_status_pb2
from google.ads.google_ads.v1.proto.enums import ad_group_type_pb2
from google.ads.google_ads.v1.proto.enums import ad_network_type_pb2
from google.ads.google_ads.v1.proto.enums import ad_serving_optimization_status_pb2
from google.ads.google_ads.v1.proto.enums import ad_strength_pb2
from google.ads.google_ads.v1.proto.enums import ad_type_pb2
from google.ads.google_ads.v1.proto.enums import advertising_channel_sub_type_pb2
from google.ads.google_ads.v1.proto.enums import advertising_channel_type_pb2
from google.ads.google_ads.v1.proto.enums import affiliate_location_feed_relationship_type_pb2
from google.ads.google_ads.v1.proto.enums import affiliate_location_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import age_range_type_pb2
from google.ads.google_ads.v1.proto.enums import app_campaign_app_store_pb2
from google.ads.google_ads.v1.proto.enums import app_campaign_bidding_strategy_goal_type_pb2
from google.ads.google_ads.v1.proto.enums import app_payment_model_type_pb2
from google.ads.google_ads.v1.proto.enums import app_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import app_store_pb2
from google.ads.google_ads.v1.proto.enums import app_url_operating_system_type_pb2
from google.ads.google_ads.v1.proto.enums import asset_type_pb2
from google.ads.google_ads.v1.proto.enums import attribution_model_pb2
from google.ads.google_ads.v1.proto.enums import bid_modifier_source_pb2
from google.ads.google_ads.v1.proto.enums import bidding_source_pb2
from google.ads.google_ads.v1.proto.enums import bidding_strategy_status_pb2
from google.ads.google_ads.v1.proto.enums import bidding_strategy_type_pb2
from google.ads.google_ads.v1.proto.enums import billing_setup_status_pb2
from google.ads.google_ads.v1.proto.enums import brand_safety_suitability_pb2
from google.ads.google_ads.v1.proto.enums import budget_delivery_method_pb2
from google.ads.google_ads.v1.proto.enums import budget_period_pb2
from google.ads.google_ads.v1.proto.enums import budget_status_pb2
from google.ads.google_ads.v1.proto.enums import budget_type_pb2
from google.ads.google_ads.v1.proto.enums import call_conversion_reporting_state_pb2
from google.ads.google_ads.v1.proto.enums import call_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import callout_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import campaign_criterion_status_pb2
from google.ads.google_ads.v1.proto.enums import campaign_draft_status_pb2
from google.ads.google_ads.v1.proto.enums import campaign_experiment_status_pb2
from google.ads.google_ads.v1.proto.enums import campaign_experiment_traffic_split_type_pb2
from google.ads.google_ads.v1.proto.enums import campaign_experiment_type_pb2
from google.ads.google_ads.v1.proto.enums import campaign_serving_status_pb2
from google.ads.google_ads.v1.proto.enums import campaign_shared_set_status_pb2
from google.ads.google_ads.v1.proto.enums import campaign_status_pb2
from google.ads.google_ads.v1.proto.enums import change_status_operation_pb2
from google.ads.google_ads.v1.proto.enums import change_status_resource_type_pb2
from google.ads.google_ads.v1.proto.enums import click_type_pb2
from google.ads.google_ads.v1.proto.enums import content_label_type_pb2
from google.ads.google_ads.v1.proto.enums import conversion_action_category_pb2
from google.ads.google_ads.v1.proto.enums import conversion_action_counting_type_pb2
from google.ads.google_ads.v1.proto.enums import conversion_action_status_pb2
from google.ads.google_ads.v1.proto.enums import conversion_action_type_pb2
from google.ads.google_ads.v1.proto.enums import conversion_adjustment_type_pb2
from google.ads.google_ads.v1.proto.enums import conversion_attribution_event_type_pb2
from google.ads.google_ads.v1.proto.enums import conversion_lag_bucket_pb2
from google.ads.google_ads.v1.proto.enums import conversion_or_adjustment_lag_bucket_pb2
from google.ads.google_ads.v1.proto.enums import criterion_category_channel_availability_mode_pb2
from google.ads.google_ads.v1.proto.enums import criterion_category_locale_availability_mode_pb2
from google.ads.google_ads.v1.proto.enums import criterion_system_serving_status_pb2
from google.ads.google_ads.v1.proto.enums import criterion_type_pb2
from google.ads.google_ads.v1.proto.enums import custom_interest_member_type_pb2
from google.ads.google_ads.v1.proto.enums import custom_interest_status_pb2
from google.ads.google_ads.v1.proto.enums import custom_interest_type_pb2
from google.ads.google_ads.v1.proto.enums import custom_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import customer_match_upload_key_type_pb2
from google.ads.google_ads.v1.proto.enums import customer_pay_per_conversion_eligibility_failure_reason_pb2
from google.ads.google_ads.v1.proto.enums import data_driven_model_status_pb2
from google.ads.google_ads.v1.proto.enums import day_of_week_pb2
from google.ads.google_ads.v1.proto.enums import device_pb2
from google.ads.google_ads.v1.proto.enums import display_ad_format_setting_pb2
from google.ads.google_ads.v1.proto.enums import display_upload_product_type_pb2
from google.ads.google_ads.v1.proto.enums import dsa_page_feed_criterion_field_pb2
from google.ads.google_ads.v1.proto.enums import education_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import extension_setting_device_pb2
from google.ads.google_ads.v1.proto.enums import extension_type_pb2
from google.ads.google_ads.v1.proto.enums import external_conversion_source_pb2
from google.ads.google_ads.v1.proto.enums import feed_attribute_type_pb2
from google.ads.google_ads.v1.proto.enums import feed_item_quality_approval_status_pb2
from google.ads.google_ads.v1.proto.enums import feed_item_quality_disapproval_reason_pb2
from google.ads.google_ads.v1.proto.enums import feed_item_status_pb2
from google.ads.google_ads.v1.proto.enums import feed_item_target_device_pb2
from google.ads.google_ads.v1.proto.enums import feed_item_target_type_pb2
from google.ads.google_ads.v1.proto.enums import feed_item_validation_status_pb2
from google.ads.google_ads.v1.proto.enums import feed_link_status_pb2
from google.ads.google_ads.v1.proto.enums import feed_mapping_criterion_type_pb2
from google.ads.google_ads.v1.proto.enums import feed_mapping_status_pb2
from google.ads.google_ads.v1.proto.enums import feed_origin_pb2
from google.ads.google_ads.v1.proto.enums import feed_status_pb2
from google.ads.google_ads.v1.proto.enums import flight_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import frequency_cap_event_type_pb2
from google.ads.google_ads.v1.proto.enums import frequency_cap_level_pb2
from google.ads.google_ads.v1.proto.enums import frequency_cap_time_unit_pb2
from google.ads.google_ads.v1.proto.enums import gender_type_pb2
from google.ads.google_ads.v1.proto.enums import geo_target_constant_status_pb2
from google.ads.google_ads.v1.proto.enums import geo_targeting_restriction_pb2
from google.ads.google_ads.v1.proto.enums import geo_targeting_type_pb2
from google.ads.google_ads.v1.proto.enums import google_ads_field_category_pb2
from google.ads.google_ads.v1.proto.enums import google_ads_field_data_type_pb2
from google.ads.google_ads.v1.proto.enums import hotel_date_selection_type_pb2
from google.ads.google_ads.v1.proto.enums import hotel_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import hotel_rate_type_pb2
from google.ads.google_ads.v1.proto.enums import income_range_type_pb2
from google.ads.google_ads.v1.proto.enums import interaction_event_type_pb2
from google.ads.google_ads.v1.proto.enums import interaction_type_pb2
from google.ads.google_ads.v1.proto.enums import job_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import keyword_match_type_pb2
from google.ads.google_ads.v1.proto.enums import keyword_plan_competition_level_pb2
from google.ads.google_ads.v1.proto.enums import keyword_plan_forecast_interval_pb2
from google.ads.google_ads.v1.proto.enums import keyword_plan_network_pb2
from google.ads.google_ads.v1.proto.enums import label_status_pb2
from google.ads.google_ads.v1.proto.enums import legacy_app_install_ad_app_store_pb2
from google.ads.google_ads.v1.proto.enums import listing_custom_attribute_index_pb2
from google.ads.google_ads.v1.proto.enums import listing_group_type_pb2
from google.ads.google_ads.v1.proto.enums import local_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import location_extension_targeting_criterion_field_pb2
from google.ads.google_ads.v1.proto.enums import location_group_radius_units_pb2
from google.ads.google_ads.v1.proto.enums import location_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import manager_link_status_pb2
from google.ads.google_ads.v1.proto.enums import matching_function_context_type_pb2
from google.ads.google_ads.v1.proto.enums import matching_function_operator_pb2
from google.ads.google_ads.v1.proto.enums import media_type_pb2
from google.ads.google_ads.v1.proto.enums import merchant_center_link_status_pb2
from google.ads.google_ads.v1.proto.enums import message_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import mime_type_pb2
from google.ads.google_ads.v1.proto.enums import minute_of_hour_pb2
from google.ads.google_ads.v1.proto.enums import mobile_device_type_pb2
from google.ads.google_ads.v1.proto.enums import month_of_year_pb2
from google.ads.google_ads.v1.proto.enums import mutate_job_status_pb2
from google.ads.google_ads.v1.proto.enums import negative_geo_target_type_pb2
from google.ads.google_ads.v1.proto.enums import operating_system_version_operator_type_pb2
from google.ads.google_ads.v1.proto.enums import page_one_promoted_strategy_goal_pb2
from google.ads.google_ads.v1.proto.enums import parental_status_type_pb2
from google.ads.google_ads.v1.proto.enums import payment_mode_pb2
from google.ads.google_ads.v1.proto.enums import placeholder_type_pb2
from google.ads.google_ads.v1.proto.enums import placement_type_pb2
from google.ads.google_ads.v1.proto.enums import policy_approval_status_pb2
from google.ads.google_ads.v1.proto.enums import policy_review_status_pb2
from google.ads.google_ads.v1.proto.enums import policy_topic_entry_type_pb2
from google.ads.google_ads.v1.proto.enums import policy_topic_evidence_destination_mismatch_url_type_pb2
from google.ads.google_ads.v1.proto.enums import policy_topic_evidence_destination_not_working_device_pb2
from google.ads.google_ads.v1.proto.enums import positive_geo_target_type_pb2
from google.ads.google_ads.v1.proto.enums import preferred_content_type_pb2
from google.ads.google_ads.v1.proto.enums import price_extension_price_qualifier_pb2
from google.ads.google_ads.v1.proto.enums import price_extension_price_unit_pb2
from google.ads.google_ads.v1.proto.enums import price_extension_type_pb2
from google.ads.google_ads.v1.proto.enums import price_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import product_bidding_category_level_pb2
from google.ads.google_ads.v1.proto.enums import product_bidding_category_status_pb2
from google.ads.google_ads.v1.proto.enums import product_channel_exclusivity_pb2
from google.ads.google_ads.v1.proto.enums import product_channel_pb2
from google.ads.google_ads.v1.proto.enums import product_condition_pb2
from google.ads.google_ads.v1.proto.enums import product_type_level_pb2
from google.ads.google_ads.v1.proto.enums import promotion_extension_discount_modifier_pb2
from google.ads.google_ads.v1.proto.enums import promotion_extension_occasion_pb2
from google.ads.google_ads.v1.proto.enums import promotion_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import proximity_radius_units_pb2
from google.ads.google_ads.v1.proto.enums import quality_score_bucket_pb2
from google.ads.google_ads.v1.proto.enums import real_estate_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import recommendation_type_pb2
from google.ads.google_ads.v1.proto.enums import search_engine_results_page_type_pb2
from google.ads.google_ads.v1.proto.enums import search_term_match_type_pb2
from google.ads.google_ads.v1.proto.enums import search_term_targeting_status_pb2
from google.ads.google_ads.v1.proto.enums import served_asset_field_type_pb2
from google.ads.google_ads.v1.proto.enums import shared_set_status_pb2
from google.ads.google_ads.v1.proto.enums import shared_set_type_pb2
from google.ads.google_ads.v1.proto.enums import simulation_modification_method_pb2
from google.ads.google_ads.v1.proto.enums import simulation_type_pb2
from google.ads.google_ads.v1.proto.enums import sitelink_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import slot_pb2
from google.ads.google_ads.v1.proto.enums import spending_limit_type_pb2
from google.ads.google_ads.v1.proto.enums import structured_snippet_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import system_managed_entity_source_pb2
from google.ads.google_ads.v1.proto.enums import target_cpa_opt_in_recommendation_goal_pb2
from google.ads.google_ads.v1.proto.enums import target_impression_share_location_pb2
from google.ads.google_ads.v1.proto.enums import targeting_dimension_pb2
from google.ads.google_ads.v1.proto.enums import time_type_pb2
from google.ads.google_ads.v1.proto.enums import tracking_code_page_format_pb2
from google.ads.google_ads.v1.proto.enums import tracking_code_type_pb2
from google.ads.google_ads.v1.proto.enums import travel_placeholder_field_pb2
from google.ads.google_ads.v1.proto.enums import user_interest_taxonomy_type_pb2
from google.ads.google_ads.v1.proto.enums import user_list_access_status_pb2
from google.ads.google_ads.v1.proto.enums import user_list_closing_reason_pb2
from google.ads.google_ads.v1.proto.enums import user_list_combined_rule_operator_pb2
from google.ads.google_ads.v1.proto.enums import user_list_crm_data_source_type_pb2
from google.ads.google_ads.v1.proto.enums import user_list_date_rule_item_operator_pb2
from google.ads.google_ads.v1.proto.enums import user_list_logical_rule_operator_pb2
from google.ads.google_ads.v1.proto.enums import user_list_membership_status_pb2
from google.ads.google_ads.v1.proto.enums import user_list_number_rule_item_operator_pb2
from google.ads.google_ads.v1.proto.enums import user_list_prepopulation_status_pb2
from google.ads.google_ads.v1.proto.enums import user_list_rule_type_pb2
from google.ads.google_ads.v1.proto.enums import user_list_size_range_pb2
from google.ads.google_ads.v1.proto.enums import user_list_string_rule_item_operator_pb2
from google.ads.google_ads.v1.proto.enums import user_list_type_pb2
from google.ads.google_ads.v1.proto.enums import vanity_pharma_display_url_mode_pb2
from google.ads.google_ads.v1.proto.enums import vanity_pharma_text_pb2
from google.ads.google_ads.v1.proto.enums import webpage_condition_operand_pb2
from google.ads.google_ads.v1.proto.enums import webpage_condition_operator_pb2
from google.ads.google_ads.v1.proto.errors import account_budget_proposal_error_pb2
from google.ads.google_ads.v1.proto.errors import ad_customizer_error_pb2
from google.ads.google_ads.v1.proto.errors import ad_error_pb2
from google.ads.google_ads.v1.proto.errors import ad_group_ad_error_pb2
from google.ads.google_ads.v1.proto.errors import ad_group_bid_modifier_error_pb2
from google.ads.google_ads.v1.proto.errors import ad_group_criterion_error_pb2
from google.ads.google_ads.v1.proto.errors import ad_group_error_pb2
from google.ads.google_ads.v1.proto.errors import ad_group_feed_error_pb2
from google.ads.google_ads.v1.proto.errors import ad_parameter_error_pb2
from google.ads.google_ads.v1.proto.errors import ad_sharing_error_pb2
from google.ads.google_ads.v1.proto.errors import adx_error_pb2
from google.ads.google_ads.v1.proto.errors import asset_error_pb2
from google.ads.google_ads.v1.proto.errors import authentication_error_pb2
from google.ads.google_ads.v1.proto.errors import authorization_error_pb2
from google.ads.google_ads.v1.proto.errors import bidding_error_pb2
from google.ads.google_ads.v1.proto.errors import bidding_strategy_error_pb2
from google.ads.google_ads.v1.proto.errors import billing_setup_error_pb2
from google.ads.google_ads.v1.proto.errors import campaign_budget_error_pb2
from google.ads.google_ads.v1.proto.errors import campaign_criterion_error_pb2
from google.ads.google_ads.v1.proto.errors import campaign_draft_error_pb2
from google.ads.google_ads.v1.proto.errors import campaign_error_pb2
from google.ads.google_ads.v1.proto.errors import campaign_experiment_error_pb2
from google.ads.google_ads.v1.proto.errors import campaign_feed_error_pb2
from google.ads.google_ads.v1.proto.errors import campaign_shared_set_error_pb2
from google.ads.google_ads.v1.proto.errors import change_status_error_pb2
from google.ads.google_ads.v1.proto.errors import collection_size_error_pb2
from google.ads.google_ads.v1.proto.errors import context_error_pb2
from google.ads.google_ads.v1.proto.errors import conversion_action_error_pb2
from google.ads.google_ads.v1.proto.errors import conversion_adjustment_upload_error_pb2
from google.ads.google_ads.v1.proto.errors import conversion_upload_error_pb2
from google.ads.google_ads.v1.proto.errors import country_code_error_pb2
from google.ads.google_ads.v1.proto.errors import criterion_error_pb2
from google.ads.google_ads.v1.proto.errors import custom_interest_error_pb2
from google.ads.google_ads.v1.proto.errors import customer_client_link_error_pb2
from google.ads.google_ads.v1.proto.errors import customer_error_pb2
from google.ads.google_ads.v1.proto.errors import customer_feed_error_pb2
from google.ads.google_ads.v1.proto.errors import customer_manager_link_error_pb2
from google.ads.google_ads.v1.proto.errors import database_error_pb2
from google.ads.google_ads.v1.proto.errors import date_error_pb2
from google.ads.google_ads.v1.proto.errors import date_range_error_pb2
from google.ads.google_ads.v1.proto.errors import distinct_error_pb2
from google.ads.google_ads.v1.proto.errors import enum_error_pb2
from google.ads.google_ads.v1.proto.errors import errors_pb2
from google.ads.google_ads.v1.proto.errors import extension_feed_item_error_pb2
from google.ads.google_ads.v1.proto.errors import extension_setting_error_pb2
from google.ads.google_ads.v1.proto.errors import feed_attribute_reference_error_pb2
from google.ads.google_ads.v1.proto.errors import feed_error_pb2
from google.ads.google_ads.v1.proto.errors import feed_item_error_pb2
from google.ads.google_ads.v1.proto.errors import feed_item_target_error_pb2
from google.ads.google_ads.v1.proto.errors import feed_item_validation_error_pb2
from google.ads.google_ads.v1.proto.errors import feed_mapping_error_pb2
from google.ads.google_ads.v1.proto.errors import field_error_pb2
from google.ads.google_ads.v1.proto.errors import field_mask_error_pb2
from google.ads.google_ads.v1.proto.errors import function_error_pb2
from google.ads.google_ads.v1.proto.errors import function_parsing_error_pb2
from google.ads.google_ads.v1.proto.errors import geo_target_constant_suggestion_error_pb2
from google.ads.google_ads.v1.proto.errors import header_error_pb2
from google.ads.google_ads.v1.proto.errors import id_error_pb2
from google.ads.google_ads.v1.proto.errors import image_error_pb2
from google.ads.google_ads.v1.proto.errors import internal_error_pb2
from google.ads.google_ads.v1.proto.errors import keyword_plan_ad_group_error_pb2
from google.ads.google_ads.v1.proto.errors import keyword_plan_campaign_error_pb2
from google.ads.google_ads.v1.proto.errors import keyword_plan_error_pb2
from google.ads.google_ads.v1.proto.errors import keyword_plan_idea_error_pb2
from google.ads.google_ads.v1.proto.errors import keyword_plan_keyword_error_pb2
from google.ads.google_ads.v1.proto.errors import keyword_plan_negative_keyword_error_pb2
from google.ads.google_ads.v1.proto.errors import label_error_pb2
from google.ads.google_ads.v1.proto.errors import language_code_error_pb2
from google.ads.google_ads.v1.proto.errors import list_operation_error_pb2
from google.ads.google_ads.v1.proto.errors import manager_link_error_pb2
from google.ads.google_ads.v1.proto.errors import media_bundle_error_pb2
from google.ads.google_ads.v1.proto.errors import media_file_error_pb2
from google.ads.google_ads.v1.proto.errors import media_upload_error_pb2
from google.ads.google_ads.v1.proto.errors import multiplier_error_pb2
from google.ads.google_ads.v1.proto.errors import mutate_error_pb2
from google.ads.google_ads.v1.proto.errors import mutate_job_error_pb2
from google.ads.google_ads.v1.proto.errors import new_resource_creation_error_pb2
from google.ads.google_ads.v1.proto.errors import not_empty_error_pb2
from google.ads.google_ads.v1.proto.errors import not_whitelisted_error_pb2
from google.ads.google_ads.v1.proto.errors import null_error_pb2
from google.ads.google_ads.v1.proto.errors import operation_access_denied_error_pb2
from google.ads.google_ads.v1.proto.errors import operator_error_pb2
from google.ads.google_ads.v1.proto.errors import partial_failure_error_pb2
from google.ads.google_ads.v1.proto.errors import policy_finding_error_pb2
from google.ads.google_ads.v1.proto.errors import policy_validation_parameter_error_pb2
from google.ads.google_ads.v1.proto.errors import policy_violation_error_pb2
from google.ads.google_ads.v1.proto.errors import query_error_pb2
from google.ads.google_ads.v1.proto.errors import quota_error_pb2
from google.ads.google_ads.v1.proto.errors import range_error_pb2
from google.ads.google_ads.v1.proto.errors import recommendation_error_pb2
from google.ads.google_ads.v1.proto.errors import region_code_error_pb2
from google.ads.google_ads.v1.proto.errors import request_error_pb2
from google.ads.google_ads.v1.proto.errors import resource_access_denied_error_pb2
from google.ads.google_ads.v1.proto.errors import resource_count_limit_exceeded_error_pb2
from google.ads.google_ads.v1.proto.errors import setting_error_pb2
from google.ads.google_ads.v1.proto.errors import shared_criterion_error_pb2
from google.ads.google_ads.v1.proto.errors import shared_set_error_pb2
from google.ads.google_ads.v1.proto.errors import size_limit_error_pb2
from google.ads.google_ads.v1.proto.errors import string_format_error_pb2
from google.ads.google_ads.v1.proto.errors import string_length_error_pb2
from google.ads.google_ads.v1.proto.errors import url_field_error_pb2
from google.ads.google_ads.v1.proto.errors import user_list_error_pb2
from google.ads.google_ads.v1.proto.errors import youtube_video_registration_error_pb2
from google.ads.google_ads.v1.proto.resources import account_budget_pb2
from google.ads.google_ads.v1.proto.resources import account_budget_proposal_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_ad_label_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_ad_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_audience_view_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_bid_modifier_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_criterion_label_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_criterion_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_criterion_simulation_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_extension_setting_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_feed_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_label_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_pb2
from google.ads.google_ads.v1.proto.resources import ad_group_simulation_pb2
from google.ads.google_ads.v1.proto.resources import ad_parameter_pb2
from google.ads.google_ads.v1.proto.resources import ad_pb2
from google.ads.google_ads.v1.proto.resources import ad_schedule_view_pb2
from google.ads.google_ads.v1.proto.resources import age_range_view_pb2
from google.ads.google_ads.v1.proto.resources import asset_pb2
from google.ads.google_ads.v1.proto.resources import bidding_strategy_pb2
from google.ads.google_ads.v1.proto.resources import billing_setup_pb2
from google.ads.google_ads.v1.proto.resources import campaign_audience_view_pb2
from google.ads.google_ads.v1.proto.resources import campaign_bid_modifier_pb2
from google.ads.google_ads.v1.proto.resources import campaign_budget_pb2
from google.ads.google_ads.v1.proto.resources import campaign_criterion_pb2
from google.ads.google_ads.v1.proto.resources import campaign_criterion_simulation_pb2
from google.ads.google_ads.v1.proto.resources import campaign_draft_pb2
from google.ads.google_ads.v1.proto.resources import campaign_experiment_pb2
from google.ads.google_ads.v1.proto.resources import campaign_extension_setting_pb2
from google.ads.google_ads.v1.proto.resources import campaign_feed_pb2
from google.ads.google_ads.v1.proto.resources import campaign_label_pb2
from google.ads.google_ads.v1.proto.resources import campaign_pb2
from google.ads.google_ads.v1.proto.resources import campaign_shared_set_pb2
from google.ads.google_ads.v1.proto.resources import carrier_constant_pb2
from google.ads.google_ads.v1.proto.resources import change_status_pb2
from google.ads.google_ads.v1.proto.resources import click_view_pb2
from google.ads.google_ads.v1.proto.resources import conversion_action_pb2
from google.ads.google_ads.v1.proto.resources import custom_interest_pb2
from google.ads.google_ads.v1.proto.resources import customer_client_link_pb2
from google.ads.google_ads.v1.proto.resources import customer_client_pb2
from google.ads.google_ads.v1.proto.resources import customer_extension_setting_pb2
from google.ads.google_ads.v1.proto.resources import customer_feed_pb2
from google.ads.google_ads.v1.proto.resources import customer_label_pb2
from google.ads.google_ads.v1.proto.resources import customer_manager_link_pb2
from google.ads.google_ads.v1.proto.resources import customer_negative_criterion_pb2
from google.ads.google_ads.v1.proto.resources import customer_pb2
from google.ads.google_ads.v1.proto.resources import detail_placement_view_pb2
from google.ads.google_ads.v1.proto.resources import display_keyword_view_pb2
from google.ads.google_ads.v1.proto.resources import domain_category_pb2
from google.ads.google_ads.v1.proto.resources import dynamic_search_ads_search_term_view_pb2
from google.ads.google_ads.v1.proto.resources import expanded_landing_page_view_pb2
from google.ads.google_ads.v1.proto.resources import extension_feed_item_pb2
from google.ads.google_ads.v1.proto.resources import feed_item_pb2
from google.ads.google_ads.v1.proto.resources import feed_item_target_pb2
from google.ads.google_ads.v1.proto.resources import feed_mapping_pb2
from google.ads.google_ads.v1.proto.resources import feed_pb2
from google.ads.google_ads.v1.proto.resources import feed_placeholder_view_pb2
from google.ads.google_ads.v1.proto.resources import gender_view_pb2
from google.ads.google_ads.v1.proto.resources import geo_target_constant_pb2
from google.ads.google_ads.v1.proto.resources import geographic_view_pb2
from google.ads.google_ads.v1.proto.resources import google_ads_field_pb2
from google.ads.google_ads.v1.proto.resources import group_placement_view_pb2
from google.ads.google_ads.v1.proto.resources import hotel_group_view_pb2
from google.ads.google_ads.v1.proto.resources import hotel_performance_view_pb2
from google.ads.google_ads.v1.proto.resources import keyword_plan_ad_group_pb2
from google.ads.google_ads.v1.proto.resources import keyword_plan_campaign_pb2
from google.ads.google_ads.v1.proto.resources import keyword_plan_keyword_pb2
from google.ads.google_ads.v1.proto.resources import keyword_plan_negative_keyword_pb2
from google.ads.google_ads.v1.proto.resources import keyword_plan_pb2
from google.ads.google_ads.v1.proto.resources import keyword_view_pb2
from google.ads.google_ads.v1.proto.resources import label_pb2
from google.ads.google_ads.v1.proto.resources import landing_page_view_pb2
from google.ads.google_ads.v1.proto.resources import language_constant_pb2
from google.ads.google_ads.v1.proto.resources import location_view_pb2
from google.ads.google_ads.v1.proto.resources import managed_placement_view_pb2
from google.ads.google_ads.v1.proto.resources import media_file_pb2
from google.ads.google_ads.v1.proto.resources import merchant_center_link_pb2
from google.ads.google_ads.v1.proto.resources import mobile_app_category_constant_pb2
from google.ads.google_ads.v1.proto.resources import mobile_device_constant_pb2
from google.ads.google_ads.v1.proto.resources import mutate_job_pb2
from google.ads.google_ads.v1.proto.resources import operating_system_version_constant_pb2
from google.ads.google_ads.v1.proto.resources import paid_organic_search_term_view_pb2
from google.ads.google_ads.v1.proto.resources import parental_status_view_pb2
from google.ads.google_ads.v1.proto.resources import payments_account_pb2
from google.ads.google_ads.v1.proto.resources import product_bidding_category_constant_pb2
from google.ads.google_ads.v1.proto.resources import product_group_view_pb2
from google.ads.google_ads.v1.proto.resources import recommendation_pb2
from google.ads.google_ads.v1.proto.resources import remarketing_action_pb2
from google.ads.google_ads.v1.proto.resources import search_term_view_pb2
from google.ads.google_ads.v1.proto.resources import shared_criterion_pb2
from google.ads.google_ads.v1.proto.resources import shared_set_pb2
from google.ads.google_ads.v1.proto.resources import shopping_performance_view_pb2
from google.ads.google_ads.v1.proto.resources import topic_constant_pb2
from google.ads.google_ads.v1.proto.resources import topic_view_pb2
from google.ads.google_ads.v1.proto.resources import user_interest_pb2
from google.ads.google_ads.v1.proto.resources import user_list_pb2
from google.ads.google_ads.v1.proto.resources import video_pb2
from google.ads.google_ads.v1.proto.services import account_budget_proposal_service_pb2
from google.ads.google_ads.v1.proto.services import account_budget_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_ad_label_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_ad_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_audience_view_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_bid_modifier_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_criterion_label_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_criterion_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_criterion_simulation_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_extension_setting_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_feed_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_label_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_service_pb2
from google.ads.google_ads.v1.proto.services import ad_group_simulation_service_pb2
from google.ads.google_ads.v1.proto.services import ad_parameter_service_pb2
from google.ads.google_ads.v1.proto.services import ad_schedule_view_service_pb2
from google.ads.google_ads.v1.proto.services import age_range_view_service_pb2
from google.ads.google_ads.v1.proto.services import asset_service_pb2
from google.ads.google_ads.v1.proto.services import bidding_strategy_service_pb2
from google.ads.google_ads.v1.proto.services import billing_setup_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_audience_view_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_bid_modifier_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_budget_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_criterion_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_criterion_simulation_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_draft_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_experiment_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_extension_setting_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_feed_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_label_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_service_pb2
from google.ads.google_ads.v1.proto.services import campaign_shared_set_service_pb2
from google.ads.google_ads.v1.proto.services import carrier_constant_service_pb2
from google.ads.google_ads.v1.proto.services import change_status_service_pb2
from google.ads.google_ads.v1.proto.services import click_view_service_pb2
from google.ads.google_ads.v1.proto.services import conversion_action_service_pb2
from google.ads.google_ads.v1.proto.services import conversion_adjustment_upload_service_pb2
from google.ads.google_ads.v1.proto.services import conversion_upload_service_pb2
from google.ads.google_ads.v1.proto.services import custom_interest_service_pb2
from google.ads.google_ads.v1.proto.services import customer_client_link_service_pb2
from google.ads.google_ads.v1.proto.services import customer_client_service_pb2
from google.ads.google_ads.v1.proto.services import customer_extension_setting_service_pb2
from google.ads.google_ads.v1.proto.services import customer_feed_service_pb2
from google.ads.google_ads.v1.proto.services import customer_label_service_pb2
from google.ads.google_ads.v1.proto.services import customer_manager_link_service_pb2
from google.ads.google_ads.v1.proto.services import customer_negative_criterion_service_pb2
from google.ads.google_ads.v1.proto.services import customer_service_pb2
from google.ads.google_ads.v1.proto.services import detail_placement_view_service_pb2
from google.ads.google_ads.v1.proto.services import display_keyword_view_service_pb2
from google.ads.google_ads.v1.proto.services import domain_category_service_pb2
from google.ads.google_ads.v1.proto.services import dynamic_search_ads_search_term_view_service_pb2
from google.ads.google_ads.v1.proto.services import expanded_landing_page_view_service_pb2
from google.ads.google_ads.v1.proto.services import extension_feed_item_service_pb2
from google.ads.google_ads.v1.proto.services import feed_item_service_pb2
from google.ads.google_ads.v1.proto.services import feed_item_target_service_pb2
from google.ads.google_ads.v1.proto.services import feed_mapping_service_pb2
from google.ads.google_ads.v1.proto.services import feed_placeholder_view_service_pb2
from google.ads.google_ads.v1.proto.services import feed_service_pb2
from google.ads.google_ads.v1.proto.services import gender_view_service_pb2
from google.ads.google_ads.v1.proto.services import geo_target_constant_service_pb2
from google.ads.google_ads.v1.proto.services import geographic_view_service_pb2
from google.ads.google_ads.v1.proto.services import google_ads_field_service_pb2
from google.ads.google_ads.v1.proto.services import google_ads_service_pb2
from google.ads.google_ads.v1.proto.services import group_placement_view_service_pb2
from google.ads.google_ads.v1.proto.services import hotel_group_view_service_pb2
from google.ads.google_ads.v1.proto.services import hotel_performance_view_service_pb2
from google.ads.google_ads.v1.proto.services import keyword_plan_ad_group_service_pb2
from google.ads.google_ads.v1.proto.services import keyword_plan_campaign_service_pb2
from google.ads.google_ads.v1.proto.services import keyword_plan_idea_service_pb2
from google.ads.google_ads.v1.proto.services import keyword_plan_keyword_service_pb2
from google.ads.google_ads.v1.proto.services import keyword_plan_negative_keyword_service_pb2
from google.ads.google_ads.v1.proto.services import keyword_plan_service_pb2
from google.ads.google_ads.v1.proto.services import keyword_view_service_pb2
from google.ads.google_ads.v1.proto.services import label_service_pb2
from google.ads.google_ads.v1.proto.services import landing_page_view_service_pb2
from google.ads.google_ads.v1.proto.services import language_constant_service_pb2
from google.ads.google_ads.v1.proto.services import location_view_service_pb2
from google.ads.google_ads.v1.proto.services import managed_placement_view_service_pb2
from google.ads.google_ads.v1.proto.services import media_file_service_pb2
from google.ads.google_ads.v1.proto.services import merchant_center_link_service_pb2
from google.ads.google_ads.v1.proto.services import mobile_app_category_constant_service_pb2
from google.ads.google_ads.v1.proto.services import mobile_device_constant_service_pb2
from google.ads.google_ads.v1.proto.services import mutate_job_service_pb2
from google.ads.google_ads.v1.proto.services import operating_system_version_constant_service_pb2
from google.ads.google_ads.v1.proto.services import paid_organic_search_term_view_service_pb2
from google.ads.google_ads.v1.proto.services import parental_status_view_service_pb2
from google.ads.google_ads.v1.proto.services import payments_account_service_pb2
from google.ads.google_ads.v1.proto.services import product_bidding_category_constant_service_pb2
from google.ads.google_ads.v1.proto.services import product_group_view_service_pb2
from google.ads.google_ads.v1.proto.services import recommendation_service_pb2
from google.ads.google_ads.v1.proto.services import remarketing_action_service_pb2
from google.ads.google_ads.v1.proto.services import search_term_view_service_pb2
from google.ads.google_ads.v1.proto.services import shared_criterion_service_pb2
from google.ads.google_ads.v1.proto.services import shared_set_service_pb2
from google.ads.google_ads.v1.proto.services import shopping_performance_view_service_pb2
from google.ads.google_ads.v1.proto.services import topic_constant_service_pb2
from google.ads.google_ads.v1.proto.services import topic_view_service_pb2
from google.ads.google_ads.v1.proto.services import user_interest_service_pb2
from google.ads.google_ads.v1.proto.services import user_list_service_pb2
from google.ads.google_ads.v1.proto.services import video_service_pb2
from google.longrunning import operations_pb2
from google.protobuf import any_pb2
from google.protobuf import empty_pb2
from google.protobuf import field_mask_pb2
from google.protobuf import wrappers_pb2
from google.rpc import status_pb2

_shared_modules = [
    ad_asset_pb2,
    ad_type_infos_pb2,
    asset_types_pb2,
    bidding_pb2,
    click_location_pb2,
    criteria_pb2,
    criterion_category_availability_pb2,
    custom_parameter_pb2,
    dates_pb2,
    explorer_auto_optimizer_setting_pb2,
    extensions_pb2,
    feed_common_pb2,
    final_app_url_pb2,
    frequency_cap_pb2,
    keyword_plan_common_pb2,
    matching_function_pb2,
    metrics_pb2,
    policy_pb2,
    real_time_bidding_setting_pb2,
    segments_pb2,
    simulation_pb2,
    tag_snippet_pb2,
    targeting_setting_pb2,
    text_label_pb2,
    url_collection_pb2,
    user_lists_pb2,
    value_pb2,
    access_reason_pb2,
    account_budget_proposal_status_pb2,
    account_budget_proposal_type_pb2,
    account_budget_status_pb2,
    ad_customizer_placeholder_field_pb2,
    ad_group_ad_rotation_mode_pb2,
    ad_group_ad_status_pb2,
    ad_group_criterion_approval_status_pb2,
    ad_group_criterion_status_pb2,
    ad_group_status_pb2,
    ad_group_type_pb2,
    ad_network_type_pb2,
    ad_serving_optimization_status_pb2,
    ad_strength_pb2,
    ad_type_pb2,
    advertising_channel_sub_type_pb2,
    advertising_channel_type_pb2,
    affiliate_location_feed_relationship_type_pb2,
    affiliate_location_placeholder_field_pb2,
    age_range_type_pb2,
    app_campaign_app_store_pb2,
    app_campaign_bidding_strategy_goal_type_pb2,
    app_payment_model_type_pb2,
    app_placeholder_field_pb2,
    app_store_pb2,
    app_url_operating_system_type_pb2,
    asset_type_pb2,
    attribution_model_pb2,
    bid_modifier_source_pb2,
    bidding_source_pb2,
    bidding_strategy_status_pb2,
    bidding_strategy_type_pb2,
    billing_setup_status_pb2,
    brand_safety_suitability_pb2,
    budget_delivery_method_pb2,
    budget_period_pb2,
    budget_status_pb2,
    budget_type_pb2,
    call_conversion_reporting_state_pb2,
    call_placeholder_field_pb2,
    callout_placeholder_field_pb2,
    campaign_criterion_status_pb2,
    campaign_draft_status_pb2,
    campaign_experiment_status_pb2,
    campaign_experiment_traffic_split_type_pb2,
    campaign_experiment_type_pb2,
    campaign_serving_status_pb2,
    campaign_shared_set_status_pb2,
    campaign_status_pb2,
    change_status_operation_pb2,
    change_status_resource_type_pb2,
    click_type_pb2,
    content_label_type_pb2,
    conversion_action_category_pb2,
    conversion_action_counting_type_pb2,
    conversion_action_status_pb2,
    conversion_action_type_pb2,
    conversion_adjustment_type_pb2,
    conversion_attribution_event_type_pb2,
    conversion_lag_bucket_pb2,
    conversion_or_adjustment_lag_bucket_pb2,
    criterion_category_channel_availability_mode_pb2,
    criterion_category_locale_availability_mode_pb2,
    criterion_system_serving_status_pb2,
    criterion_type_pb2,
    custom_interest_member_type_pb2,
    custom_interest_status_pb2,
    custom_interest_type_pb2,
    custom_placeholder_field_pb2,
    customer_match_upload_key_type_pb2,
    customer_pay_per_conversion_eligibility_failure_reason_pb2,
    data_driven_model_status_pb2,
    day_of_week_pb2,
    device_pb2,
    display_ad_format_setting_pb2,
    display_upload_product_type_pb2,
    dsa_page_feed_criterion_field_pb2,
    education_placeholder_field_pb2,
    extension_setting_device_pb2,
    extension_type_pb2,
    external_conversion_source_pb2,
    feed_attribute_type_pb2,
    feed_item_quality_approval_status_pb2,
    feed_item_quality_disapproval_reason_pb2,
    feed_item_status_pb2,
    feed_item_target_device_pb2,
    feed_item_target_type_pb2,
    feed_item_validation_status_pb2,
    feed_link_status_pb2,
    feed_mapping_criterion_type_pb2,
    feed_mapping_status_pb2,
    feed_origin_pb2,
    feed_status_pb2,
    flight_placeholder_field_pb2,
    frequency_cap_event_type_pb2,
    frequency_cap_level_pb2,
    frequency_cap_time_unit_pb2,
    gender_type_pb2,
    geo_target_constant_status_pb2,
    geo_targeting_restriction_pb2,
    geo_targeting_type_pb2,
    google_ads_field_category_pb2,
    google_ads_field_data_type_pb2,
    hotel_date_selection_type_pb2,
    hotel_placeholder_field_pb2,
    hotel_rate_type_pb2,
    income_range_type_pb2,
    interaction_event_type_pb2,
    interaction_type_pb2,
    job_placeholder_field_pb2,
    keyword_match_type_pb2,
    keyword_plan_competition_level_pb2,
    keyword_plan_forecast_interval_pb2,
    keyword_plan_network_pb2,
    label_status_pb2,
    legacy_app_install_ad_app_store_pb2,
    listing_custom_attribute_index_pb2,
    listing_group_type_pb2,
    local_placeholder_field_pb2,
    location_extension_targeting_criterion_field_pb2,
    location_group_radius_units_pb2,
    location_placeholder_field_pb2,
    manager_link_status_pb2,
    matching_function_context_type_pb2,
    matching_function_operator_pb2,
    media_type_pb2,
    merchant_center_link_status_pb2,
    message_placeholder_field_pb2,
    mime_type_pb2,
    minute_of_hour_pb2,
    mobile_device_type_pb2,
    month_of_year_pb2,
    mutate_job_status_pb2,
    negative_geo_target_type_pb2,
    operating_system_version_operator_type_pb2,
    page_one_promoted_strategy_goal_pb2,
    parental_status_type_pb2,
    payment_mode_pb2,
    placeholder_type_pb2,
    placement_type_pb2,
    policy_approval_status_pb2,
    policy_review_status_pb2,
    policy_topic_entry_type_pb2,
    policy_topic_evidence_destination_mismatch_url_type_pb2,
    policy_topic_evidence_destination_not_working_device_pb2,
    positive_geo_target_type_pb2,
    preferred_content_type_pb2,
    price_extension_price_qualifier_pb2,
    price_extension_price_unit_pb2,
    price_extension_type_pb2,
    price_placeholder_field_pb2,
    product_bidding_category_level_pb2,
    product_bidding_category_status_pb2,
    product_channel_exclusivity_pb2,
    product_channel_pb2,
    product_condition_pb2,
    product_type_level_pb2,
    promotion_extension_discount_modifier_pb2,
    promotion_extension_occasion_pb2,
    promotion_placeholder_field_pb2,
    proximity_radius_units_pb2,
    quality_score_bucket_pb2,
    real_estate_placeholder_field_pb2,
    recommendation_type_pb2,
    search_engine_results_page_type_pb2,
    search_term_match_type_pb2,
    search_term_targeting_status_pb2,
    served_asset_field_type_pb2,
    shared_set_status_pb2,
    shared_set_type_pb2,
    simulation_modification_method_pb2,
    simulation_type_pb2,
    sitelink_placeholder_field_pb2,
    slot_pb2,
    spending_limit_type_pb2,
    structured_snippet_placeholder_field_pb2,
    system_managed_entity_source_pb2,
    target_cpa_opt_in_recommendation_goal_pb2,
    target_impression_share_location_pb2,
    targeting_dimension_pb2,
    time_type_pb2,
    tracking_code_page_format_pb2,
    tracking_code_type_pb2,
    travel_placeholder_field_pb2,
    user_interest_taxonomy_type_pb2,
    user_list_access_status_pb2,
    user_list_closing_reason_pb2,
    user_list_combined_rule_operator_pb2,
    user_list_crm_data_source_type_pb2,
    user_list_date_rule_item_operator_pb2,
    user_list_logical_rule_operator_pb2,
    user_list_membership_status_pb2,
    user_list_number_rule_item_operator_pb2,
    user_list_prepopulation_status_pb2,
    user_list_rule_type_pb2,
    user_list_size_range_pb2,
    user_list_string_rule_item_operator_pb2,
    user_list_type_pb2,
    vanity_pharma_display_url_mode_pb2,
    vanity_pharma_text_pb2,
    webpage_condition_operand_pb2,
    webpage_condition_operator_pb2,
    account_budget_proposal_error_pb2,
    ad_customizer_error_pb2,
    ad_error_pb2,
    ad_group_ad_error_pb2,
    ad_group_bid_modifier_error_pb2,
    ad_group_criterion_error_pb2,
    ad_group_error_pb2,
    ad_group_feed_error_pb2,
    ad_parameter_error_pb2,
    ad_sharing_error_pb2,
    adx_error_pb2,
    asset_error_pb2,
    authentication_error_pb2,
    authorization_error_pb2,
    bidding_error_pb2,
    bidding_strategy_error_pb2,
    billing_setup_error_pb2,
    campaign_budget_error_pb2,
    campaign_criterion_error_pb2,
    campaign_draft_error_pb2,
    campaign_error_pb2,
    campaign_experiment_error_pb2,
    campaign_feed_error_pb2,
    campaign_shared_set_error_pb2,
    change_status_error_pb2,
    collection_size_error_pb2,
    context_error_pb2,
    conversion_action_error_pb2,
    conversion_adjustment_upload_error_pb2,
    conversion_upload_error_pb2,
    country_code_error_pb2,
    criterion_error_pb2,
    custom_interest_error_pb2,
    customer_client_link_error_pb2,
    customer_error_pb2,
    customer_feed_error_pb2,
    customer_manager_link_error_pb2,
    database_error_pb2,
    date_error_pb2,
    date_range_error_pb2,
    distinct_error_pb2,
    enum_error_pb2,
    errors_pb2,
    extension_feed_item_error_pb2,
    extension_setting_error_pb2,
    feed_attribute_reference_error_pb2,
    feed_error_pb2,
    feed_item_error_pb2,
    feed_item_target_error_pb2,
    feed_item_validation_error_pb2,
    feed_mapping_error_pb2,
    field_error_pb2,
    field_mask_error_pb2,
    function_error_pb2,
    function_parsing_error_pb2,
    geo_target_constant_suggestion_error_pb2,
    header_error_pb2,
    id_error_pb2,
    image_error_pb2,
    internal_error_pb2,
    keyword_plan_ad_group_error_pb2,
    keyword_plan_campaign_error_pb2,
    keyword_plan_error_pb2,
    keyword_plan_idea_error_pb2,
    keyword_plan_keyword_error_pb2,
    keyword_plan_negative_keyword_error_pb2,
    label_error_pb2,
    language_code_error_pb2,
    list_operation_error_pb2,
    manager_link_error_pb2,
    media_bundle_error_pb2,
    media_file_error_pb2,
    media_upload_error_pb2,
    multiplier_error_pb2,
    mutate_error_pb2,
    mutate_job_error_pb2,
    new_resource_creation_error_pb2,
    not_empty_error_pb2,
    not_whitelisted_error_pb2,
    null_error_pb2,
    operation_access_denied_error_pb2,
    operator_error_pb2,
    partial_failure_error_pb2,
    policy_finding_error_pb2,
    policy_validation_parameter_error_pb2,
    policy_violation_error_pb2,
    query_error_pb2,
    quota_error_pb2,
    range_error_pb2,
    recommendation_error_pb2,
    region_code_error_pb2,
    request_error_pb2,
    resource_access_denied_error_pb2,
    resource_count_limit_exceeded_error_pb2,
    setting_error_pb2,
    shared_criterion_error_pb2,
    shared_set_error_pb2,
    size_limit_error_pb2,
    string_format_error_pb2,
    string_length_error_pb2,
    url_field_error_pb2,
    user_list_error_pb2,
    youtube_video_registration_error_pb2,
    account_budget_pb2,
    account_budget_proposal_pb2,
    ad_group_ad_label_pb2,
    ad_group_ad_pb2,
    ad_group_audience_view_pb2,
    ad_group_bid_modifier_pb2,
    ad_group_criterion_label_pb2,
    ad_group_criterion_pb2,
    ad_group_criterion_simulation_pb2,
    ad_group_extension_setting_pb2,
    ad_group_feed_pb2,
    ad_group_label_pb2,
    ad_group_pb2,
    ad_group_simulation_pb2,
    ad_parameter_pb2,
    ad_pb2,
    ad_schedule_view_pb2,
    age_range_view_pb2,
    asset_pb2,
    bidding_strategy_pb2,
    billing_setup_pb2,
    campaign_audience_view_pb2,
    campaign_bid_modifier_pb2,
    campaign_budget_pb2,
    campaign_criterion_pb2,
    campaign_criterion_simulation_pb2,
    campaign_draft_pb2,
    campaign_experiment_pb2,
    campaign_extension_setting_pb2,
    campaign_feed_pb2,
    campaign_label_pb2,
    campaign_pb2,
    campaign_shared_set_pb2,
    carrier_constant_pb2,
    change_status_pb2,
    click_view_pb2,
    conversion_action_pb2,
    custom_interest_pb2,
    customer_client_link_pb2,
    customer_client_pb2,
    customer_extension_setting_pb2,
    customer_feed_pb2,
    customer_label_pb2,
    customer_manager_link_pb2,
    customer_negative_criterion_pb2,
    customer_pb2,
    detail_placement_view_pb2,
    display_keyword_view_pb2,
    domain_category_pb2,
    dynamic_search_ads_search_term_view_pb2,
    expanded_landing_page_view_pb2,
    extension_feed_item_pb2,
    feed_item_pb2,
    feed_item_target_pb2,
    feed_mapping_pb2,
    feed_pb2,
    feed_placeholder_view_pb2,
    gender_view_pb2,
    geo_target_constant_pb2,
    geographic_view_pb2,
    google_ads_field_pb2,
    group_placement_view_pb2,
    hotel_group_view_pb2,
    hotel_performance_view_pb2,
    keyword_plan_ad_group_pb2,
    keyword_plan_campaign_pb2,
    keyword_plan_keyword_pb2,
    keyword_plan_negative_keyword_pb2,
    keyword_plan_pb2,
    keyword_view_pb2,
    label_pb2,
    landing_page_view_pb2,
    language_constant_pb2,
    location_view_pb2,
    managed_placement_view_pb2,
    media_file_pb2,
    merchant_center_link_pb2,
    mobile_app_category_constant_pb2,
    mobile_device_constant_pb2,
    mutate_job_pb2,
    operating_system_version_constant_pb2,
    paid_organic_search_term_view_pb2,
    parental_status_view_pb2,
    payments_account_pb2,
    product_bidding_category_constant_pb2,
    product_group_view_pb2,
    recommendation_pb2,
    remarketing_action_pb2,
    search_term_view_pb2,
    shared_criterion_pb2,
    shared_set_pb2,
    shopping_performance_view_pb2,
    topic_constant_pb2,
    topic_view_pb2,
    user_interest_pb2,
    user_list_pb2,
    video_pb2,
    operations_pb2,
    any_pb2,
    empty_pb2,
    field_mask_pb2,
    wrappers_pb2,
    status_pb2,
]

_local_modules = [
    account_budget_proposal_service_pb2,
    account_budget_service_pb2,
    ad_group_ad_label_service_pb2,
    ad_group_ad_service_pb2,
    ad_group_audience_view_service_pb2,
    ad_group_bid_modifier_service_pb2,
    ad_group_criterion_label_service_pb2,
    ad_group_criterion_service_pb2,
    ad_group_criterion_simulation_service_pb2,
    ad_group_extension_setting_service_pb2,
    ad_group_feed_service_pb2,
    ad_group_label_service_pb2,
    ad_group_service_pb2,
    ad_group_simulation_service_pb2,
    ad_parameter_service_pb2,
    ad_schedule_view_service_pb2,
    age_range_view_service_pb2,
    asset_service_pb2,
    bidding_strategy_service_pb2,
    billing_setup_service_pb2,
    campaign_audience_view_service_pb2,
    campaign_bid_modifier_service_pb2,
    campaign_budget_service_pb2,
    campaign_criterion_service_pb2,
    campaign_criterion_simulation_service_pb2,
    campaign_draft_service_pb2,
    campaign_experiment_service_pb2,
    campaign_extension_setting_service_pb2,
    campaign_feed_service_pb2,
    campaign_label_service_pb2,
    campaign_service_pb2,
    campaign_shared_set_service_pb2,
    carrier_constant_service_pb2,
    change_status_service_pb2,
    click_view_service_pb2,
    conversion_action_service_pb2,
    conversion_adjustment_upload_service_pb2,
    conversion_upload_service_pb2,
    custom_interest_service_pb2,
    customer_client_link_service_pb2,
    customer_client_service_pb2,
    customer_extension_setting_service_pb2,
    customer_feed_service_pb2,
    customer_label_service_pb2,
    customer_manager_link_service_pb2,
    customer_negative_criterion_service_pb2,
    customer_service_pb2,
    detail_placement_view_service_pb2,
    display_keyword_view_service_pb2,
    domain_category_service_pb2,
    dynamic_search_ads_search_term_view_service_pb2,
    expanded_landing_page_view_service_pb2,
    extension_feed_item_service_pb2,
    feed_item_service_pb2,
    feed_item_target_service_pb2,
    feed_mapping_service_pb2,
    feed_placeholder_view_service_pb2,
    feed_service_pb2,
    gender_view_service_pb2,
    geo_target_constant_service_pb2,
    geographic_view_service_pb2,
    google_ads_field_service_pb2,
    google_ads_service_pb2,
    group_placement_view_service_pb2,
    hotel_group_view_service_pb2,
    hotel_performance_view_service_pb2,
    keyword_plan_ad_group_service_pb2,
    keyword_plan_campaign_service_pb2,
    keyword_plan_idea_service_pb2,
    keyword_plan_keyword_service_pb2,
    keyword_plan_negative_keyword_service_pb2,
    keyword_plan_service_pb2,
    keyword_view_service_pb2,
    label_service_pb2,
    landing_page_view_service_pb2,
    language_constant_service_pb2,
    location_view_service_pb2,
    managed_placement_view_service_pb2,
    media_file_service_pb2,
    merchant_center_link_service_pb2,
    mobile_app_category_constant_service_pb2,
    mobile_device_constant_service_pb2,
    mutate_job_service_pb2,
    operating_system_version_constant_service_pb2,
    paid_organic_search_term_view_service_pb2,
    parental_status_view_service_pb2,
    payments_account_service_pb2,
    product_bidding_category_constant_service_pb2,
    product_group_view_service_pb2,
    recommendation_service_pb2,
    remarketing_action_service_pb2,
    search_term_view_service_pb2,
    shared_criterion_service_pb2,
    shared_set_service_pb2,
    shopping_performance_view_service_pb2,
    topic_constant_service_pb2,
    topic_view_service_pb2,
    user_interest_service_pb2,
    user_list_service_pb2,
    video_service_pb2,
]

names = []

for module in _shared_modules:
    for name, message in get_messages(module).items():
        setattr(sys.modules[__name__], name, message)
        names.append(name)
for module in _local_modules:
    for name, message in get_messages(module).items():
        message.__module__ = 'google.ads.googleads_v1.types'
        setattr(sys.modules[__name__], name, message)
        names.append(name)

__all__ = tuple(sorted(names))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/resources/campaign_shared_set.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import campaign_shared_set_status_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__shared__set__status__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/resources/campaign_shared_set.proto',
  package='google.ads.googleads.v1.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v1.resourcesB\026CampaignSharedSetProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V1.Resources\312\002!Google\\Ads\\GoogleAds\\V1\\Resources\352\002%Google::Ads::GoogleAds::V1::Resources'),
  serialized_pb=_b('\nAgoogle/ads/googleads_v1/proto/resources/campaign_shared_set.proto\x12!google.ads.googleads.v1.resources\x1a\x44google/ads/googleads_v1/proto/enums/campaign_shared_set_status.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xf0\x01\n\x11\x43\x61mpaignSharedSet\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12.\n\x08\x63\x61mpaign\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x30\n\nshared_set\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x62\n\x06status\x18\x02 \x01(\x0e\x32R.google.ads.googleads.v1.enums.CampaignSharedSetStatusEnum.CampaignSharedSetStatusB\x83\x02\n%com.google.ads.googleads.v1.resourcesB\x16\x43\x61mpaignSharedSetProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v1/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V1.Resources\xca\x02!Google\\Ads\\GoogleAds\\V1\\Resources\xea\x02%Google::Ads::GoogleAds::V1::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__shared__set__status__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_CAMPAIGNSHAREDSET = _descriptor.Descriptor(
  name='CampaignSharedSet',
  full_name='google.ads.googleads.v1.resources.CampaignSharedSet',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v1.resources.CampaignSharedSet.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='campaign', full_name='google.ads.googleads.v1.resources.CampaignSharedSet.campaign', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='shared_set', full_name='google.ads.googleads.v1.resources.CampaignSharedSet.shared_set', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='google.ads.googleads.v1.resources.CampaignSharedSet.status', index=3,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=237,
  serialized_end=477,
)

_CAMPAIGNSHAREDSET.fields_by_name['campaign'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNSHAREDSET.fields_by_name['shared_set'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_CAMPAIGNSHAREDSET.fields_by_name['status'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_campaign__shared__set__status__pb2._CAMPAIGNSHAREDSETSTATUSENUM_CAMPAIGNSHAREDSETSTATUS
DESCRIPTOR.message_types_by_name['CampaignSharedSet'] = _CAMPAIGNSHAREDSET
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CampaignSharedSet = _reflection.GeneratedProtocolMessageType('CampaignSharedSet', (_message.Message,), dict(
  DESCRIPTOR = _CAMPAIGNSHAREDSET,
  __module__ = 'google.ads.googleads_v1.proto.resources.campaign_shared_set_pb2'
  ,
  __doc__ = """CampaignSharedSets are used for managing the shared sets associated with
  a campaign.
  
  
  Attributes:
      resource_name:
          The resource name of the campaign shared set. Campaign shared
          set resource names have the form:  ``customers/{customer_id}/c
          ampaignSharedSets/{campaign_id}~{shared_set_id}``
      campaign:
          The campaign to which the campaign shared set belongs.
      shared_set:
          The shared set associated with the campaign. This may be a
          negative keyword shared set of another customer. This customer
          should be a manager of the other customer, otherwise the
          campaign shared set will exist but have no serving effect.
          Only negative keyword shared sets can be associated with
          Shopping campaigns. Only negative placement shared sets can be
          associated with Display mobile app campaigns.
      status:
          The status of this campaign shared set. Read only.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.resources.CampaignSharedSet)
  ))
_sym_db.RegisterMessage(CampaignSharedSet)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/common/policy.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v1.proto.enums import policy_topic_entry_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__topic__entry__type__pb2
from google.ads.google_ads.v1.proto.enums import policy_topic_evidence_destination_mismatch_url_type_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__topic__evidence__destination__mismatch__url__type__pb2
from google.ads.google_ads.v1.proto.enums import policy_topic_evidence_destination_not_working_device_pb2 as google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__topic__evidence__destination__not__working__device__pb2
from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/common/policy.proto',
  package='google.ads.googleads.v1.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.commonB\013PolicyProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Common\312\002\036Google\\Ads\\GoogleAds\\V1\\Common\352\002\"Google::Ads::GoogleAds::V1::Common'),
  serialized_pb=_b('\n1google/ads/googleads_v1/proto/common/policy.proto\x12\x1egoogle.ads.googleads.v1.common\x1a\x41google/ads/googleads_v1/proto/enums/policy_topic_entry_type.proto\x1a]google/ads/googleads_v1/proto/enums/policy_topic_evidence_destination_mismatch_url_type.proto\x1a^google/ads/googleads_v1/proto/enums/policy_topic_evidence_destination_not_working_device.proto\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"}\n\x12PolicyViolationKey\x12\x31\n\x0bpolicy_name\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x34\n\x0eviolating_text\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\"\xb4\x01\n\x19PolicyValidationParameter\x12=\n\x17ignorable_policy_topics\x18\x01 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x12X\n\x1c\x65xempt_policy_violation_keys\x18\x02 \x03(\x0b\x32\x32.google.ads.googleads.v1.common.PolicyViolationKey\"\xaf\x02\n\x10PolicyTopicEntry\x12+\n\x05topic\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12Z\n\x04type\x18\x02 \x01(\x0e\x32L.google.ads.googleads.v1.enums.PolicyTopicEntryTypeEnum.PolicyTopicEntryType\x12\x46\n\tevidences\x18\x03 \x03(\x0b\x32\x33.google.ads.googleads.v1.common.PolicyTopicEvidence\x12J\n\x0b\x63onstraints\x18\x04 \x03(\x0b\x32\x35.google.ads.googleads.v1.common.PolicyTopicConstraint\"\x88\n\n\x13PolicyTopicEvidence\x12\x30\n\thttp_code\x18\x02 \x01(\x0b\x32\x1b.google.protobuf.Int32ValueH\x00\x12W\n\x0cwebsite_list\x18\x03 \x01(\x0b\x32?.google.ads.googleads.v1.common.PolicyTopicEvidence.WebsiteListH\x00\x12Q\n\ttext_list\x18\x04 \x01(\x0b\x32<.google.ads.googleads.v1.common.PolicyTopicEvidence.TextListH\x00\x12\x35\n\rlanguage_code\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueH\x00\x12h\n\x15\x64\x65stination_text_list\x18\x06 \x01(\x0b\x32G.google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationTextListH\x00\x12g\n\x14\x64\x65stination_mismatch\x18\x07 \x01(\x0b\x32G.google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationMismatchH\x00\x12l\n\x17\x64\x65stination_not_working\x18\x08 \x01(\x0b\x32I.google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationNotWorkingH\x00\x1a\x37\n\x08TextList\x12+\n\x05texts\x18\x01 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x1a=\n\x0bWebsiteList\x12.\n\x08websites\x18\x01 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x1aN\n\x13\x44\x65stinationTextList\x12\x37\n\x11\x64\x65stination_texts\x18\x01 \x03(\x0b\x32\x1c.google.protobuf.StringValue\x1a\xa9\x01\n\x13\x44\x65stinationMismatch\x12\x91\x01\n\turl_types\x18\x01 \x03(\x0e\x32~.google.ads.googleads.v1.enums.PolicyTopicEvidenceDestinationMismatchUrlTypeEnum.PolicyTopicEvidenceDestinationMismatchUrlType\x1a\x9d\x02\n\x15\x44\x65stinationNotWorking\x12\x32\n\x0c\x65xpanded_url\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x91\x01\n\x06\x64\x65vice\x18\x04 \x01(\x0e\x32\x80\x01.google.ads.googleads.v1.enums.PolicyTopicEvidenceDestinationNotWorkingDeviceEnum.PolicyTopicEvidenceDestinationNotWorkingDevice\x12<\n\x16last_checked_date_time\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x07\n\x05value\"\x93\x06\n\x15PolicyTopicConstraint\x12n\n\x17\x63ountry_constraint_list\x18\x01 \x01(\x0b\x32K.google.ads.googleads.v1.common.PolicyTopicConstraint.CountryConstraintListH\x00\x12g\n\x13reseller_constraint\x18\x02 \x01(\x0b\x32H.google.ads.googleads.v1.common.PolicyTopicConstraint.ResellerConstraintH\x00\x12z\n#certificate_missing_in_country_list\x18\x03 \x01(\x0b\x32K.google.ads.googleads.v1.common.PolicyTopicConstraint.CountryConstraintListH\x00\x12\x82\x01\n+certificate_domain_mismatch_in_country_list\x18\x04 \x01(\x0b\x32K.google.ads.googleads.v1.common.PolicyTopicConstraint.CountryConstraintListH\x00\x1a\xb2\x01\n\x15\x43ountryConstraintList\x12=\n\x18total_targeted_countries\x18\x01 \x01(\x0b\x32\x1b.google.protobuf.Int32Value\x12Z\n\tcountries\x18\x02 \x03(\x0b\x32G.google.ads.googleads.v1.common.PolicyTopicConstraint.CountryConstraint\x1a\x14\n\x12ResellerConstraint\x1aL\n\x11\x43ountryConstraint\x12\x37\n\x11\x63ountry_criterion\x18\x01 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x07\n\x05valueB\xe6\x01\n\"com.google.ads.googleads.v1.commonB\x0bPolicyProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Common\xea\x02\"Google::Ads::GoogleAds::V1::Commonb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__topic__entry__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__topic__evidence__destination__mismatch__url__type__pb2.DESCRIPTOR,google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__topic__evidence__destination__not__working__device__pb2.DESCRIPTOR,google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_POLICYVIOLATIONKEY = _descriptor.Descriptor(
  name='PolicyViolationKey',
  full_name='google.ads.googleads.v1.common.PolicyViolationKey',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='policy_name', full_name='google.ads.googleads.v1.common.PolicyViolationKey.policy_name', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='violating_text', full_name='google.ads.googleads.v1.common.PolicyViolationKey.violating_text', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=405,
  serialized_end=530,
)


_POLICYVALIDATIONPARAMETER = _descriptor.Descriptor(
  name='PolicyValidationParameter',
  full_name='google.ads.googleads.v1.common.PolicyValidationParameter',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ignorable_policy_topics', full_name='google.ads.googleads.v1.common.PolicyValidationParameter.ignorable_policy_topics', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='exempt_policy_violation_keys', full_name='google.ads.googleads.v1.common.PolicyValidationParameter.exempt_policy_violation_keys', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=533,
  serialized_end=713,
)


_POLICYTOPICENTRY = _descriptor.Descriptor(
  name='PolicyTopicEntry',
  full_name='google.ads.googleads.v1.common.PolicyTopicEntry',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='topic', full_name='google.ads.googleads.v1.common.PolicyTopicEntry.topic', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='google.ads.googleads.v1.common.PolicyTopicEntry.type', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='evidences', full_name='google.ads.googleads.v1.common.PolicyTopicEntry.evidences', index=2,
      number=3, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='constraints', full_name='google.ads.googleads.v1.common.PolicyTopicEntry.constraints', index=3,
      number=4, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=716,
  serialized_end=1019,
)


_POLICYTOPICEVIDENCE_TEXTLIST = _descriptor.Descriptor(
  name='TextList',
  full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.TextList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='texts', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.TextList.texts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1643,
  serialized_end=1698,
)

_POLICYTOPICEVIDENCE_WEBSITELIST = _descriptor.Descriptor(
  name='WebsiteList',
  full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.WebsiteList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='websites', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.WebsiteList.websites', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1700,
  serialized_end=1761,
)

_POLICYTOPICEVIDENCE_DESTINATIONTEXTLIST = _descriptor.Descriptor(
  name='DestinationTextList',
  full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationTextList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='destination_texts', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationTextList.destination_texts', index=0,
      number=1, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1763,
  serialized_end=1841,
)

_POLICYTOPICEVIDENCE_DESTINATIONMISMATCH = _descriptor.Descriptor(
  name='DestinationMismatch',
  full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationMismatch',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='url_types', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationMismatch.url_types', index=0,
      number=1, type=14, cpp_type=8, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1844,
  serialized_end=2013,
)

_POLICYTOPICEVIDENCE_DESTINATIONNOTWORKING = _descriptor.Descriptor(
  name='DestinationNotWorking',
  full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationNotWorking',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='expanded_url', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationNotWorking.expanded_url', index=0,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='device', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationNotWorking.device', index=1,
      number=4, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='last_checked_date_time', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationNotWorking.last_checked_date_time', index=2,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2016,
  serialized_end=2301,
)

_POLICYTOPICEVIDENCE = _descriptor.Descriptor(
  name='PolicyTopicEvidence',
  full_name='google.ads.googleads.v1.common.PolicyTopicEvidence',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='http_code', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.http_code', index=0,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='website_list', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.website_list', index=1,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='text_list', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.text_list', index=2,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='language_code', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.language_code', index=3,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_text_list', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.destination_text_list', index=4,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_mismatch', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.destination_mismatch', index=5,
      number=7, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='destination_not_working', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.destination_not_working', index=6,
      number=8, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_POLICYTOPICEVIDENCE_TEXTLIST, _POLICYTOPICEVIDENCE_WEBSITELIST, _POLICYTOPICEVIDENCE_DESTINATIONTEXTLIST, _POLICYTOPICEVIDENCE_DESTINATIONMISMATCH, _POLICYTOPICEVIDENCE_DESTINATIONNOTWORKING, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='google.ads.googleads.v1.common.PolicyTopicEvidence.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=1022,
  serialized_end=2310,
)


_POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINTLIST = _descriptor.Descriptor(
  name='CountryConstraintList',
  full_name='google.ads.googleads.v1.common.PolicyTopicConstraint.CountryConstraintList',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='total_targeted_countries', full_name='google.ads.googleads.v1.common.PolicyTopicConstraint.CountryConstraintList.total_targeted_countries', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='countries', full_name='google.ads.googleads.v1.common.PolicyTopicConstraint.CountryConstraintList.countries', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2813,
  serialized_end=2991,
)

_POLICYTOPICCONSTRAINT_RESELLERCONSTRAINT = _descriptor.Descriptor(
  name='ResellerConstraint',
  full_name='google.ads.googleads.v1.common.PolicyTopicConstraint.ResellerConstraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=2993,
  serialized_end=3013,
)

_POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINT = _descriptor.Descriptor(
  name='CountryConstraint',
  full_name='google.ads.googleads.v1.common.PolicyTopicConstraint.CountryConstraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country_criterion', full_name='google.ads.googleads.v1.common.PolicyTopicConstraint.CountryConstraint.country_criterion', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=3015,
  serialized_end=3091,
)

_POLICYTOPICCONSTRAINT = _descriptor.Descriptor(
  name='PolicyTopicConstraint',
  full_name='google.ads.googleads.v1.common.PolicyTopicConstraint',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='country_constraint_list', full_name='google.ads.googleads.v1.common.PolicyTopicConstraint.country_constraint_list', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='reseller_constraint', full_name='google.ads.googleads.v1.common.PolicyTopicConstraint.reseller_constraint', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='certificate_missing_in_country_list', full_name='google.ads.googleads.v1.common.PolicyTopicConstraint.certificate_missing_in_country_list', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='certificate_domain_mismatch_in_country_list', full_name='google.ads.googleads.v1.common.PolicyTopicConstraint.certificate_domain_mismatch_in_country_list', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[_POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINTLIST, _POLICYTOPICCONSTRAINT_RESELLERCONSTRAINT, _POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINT, ],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='google.ads.googleads.v1.common.PolicyTopicConstraint.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=2313,
  serialized_end=3100,
)

_POLICYVIOLATIONKEY.fields_by_name['policy_name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_POLICYVIOLATIONKEY.fields_by_name['violating_text'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_POLICYVALIDATIONPARAMETER.fields_by_name['ignorable_policy_topics'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_POLICYVALIDATIONPARAMETER.fields_by_name['exempt_policy_violation_keys'].message_type = _POLICYVIOLATIONKEY
_POLICYTOPICENTRY.fields_by_name['topic'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_POLICYTOPICENTRY.fields_by_name['type'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__topic__entry__type__pb2._POLICYTOPICENTRYTYPEENUM_POLICYTOPICENTRYTYPE
_POLICYTOPICENTRY.fields_by_name['evidences'].message_type = _POLICYTOPICEVIDENCE
_POLICYTOPICENTRY.fields_by_name['constraints'].message_type = _POLICYTOPICCONSTRAINT
_POLICYTOPICEVIDENCE_TEXTLIST.fields_by_name['texts'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_POLICYTOPICEVIDENCE_TEXTLIST.containing_type = _POLICYTOPICEVIDENCE
_POLICYTOPICEVIDENCE_WEBSITELIST.fields_by_name['websites'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_POLICYTOPICEVIDENCE_WEBSITELIST.containing_type = _POLICYTOPICEVIDENCE
_POLICYTOPICEVIDENCE_DESTINATIONTEXTLIST.fields_by_name['destination_texts'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_POLICYTOPICEVIDENCE_DESTINATIONTEXTLIST.containing_type = _POLICYTOPICEVIDENCE
_POLICYTOPICEVIDENCE_DESTINATIONMISMATCH.fields_by_name['url_types'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__topic__evidence__destination__mismatch__url__type__pb2._POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPEENUM_POLICYTOPICEVIDENCEDESTINATIONMISMATCHURLTYPE
_POLICYTOPICEVIDENCE_DESTINATIONMISMATCH.containing_type = _POLICYTOPICEVIDENCE
_POLICYTOPICEVIDENCE_DESTINATIONNOTWORKING.fields_by_name['expanded_url'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_POLICYTOPICEVIDENCE_DESTINATIONNOTWORKING.fields_by_name['device'].enum_type = google_dot_ads_dot_googleads__v1_dot_proto_dot_enums_dot_policy__topic__evidence__destination__not__working__device__pb2._POLICYTOPICEVIDENCEDESTINATIONNOTWORKINGDEVICEENUM_POLICYTOPICEVIDENCEDESTINATIONNOTWORKINGDEVICE
_POLICYTOPICEVIDENCE_DESTINATIONNOTWORKING.fields_by_name['last_checked_date_time'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_POLICYTOPICEVIDENCE_DESTINATIONNOTWORKING.containing_type = _POLICYTOPICEVIDENCE
_POLICYTOPICEVIDENCE.fields_by_name['http_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_POLICYTOPICEVIDENCE.fields_by_name['website_list'].message_type = _POLICYTOPICEVIDENCE_WEBSITELIST
_POLICYTOPICEVIDENCE.fields_by_name['text_list'].message_type = _POLICYTOPICEVIDENCE_TEXTLIST
_POLICYTOPICEVIDENCE.fields_by_name['language_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_POLICYTOPICEVIDENCE.fields_by_name['destination_text_list'].message_type = _POLICYTOPICEVIDENCE_DESTINATIONTEXTLIST
_POLICYTOPICEVIDENCE.fields_by_name['destination_mismatch'].message_type = _POLICYTOPICEVIDENCE_DESTINATIONMISMATCH
_POLICYTOPICEVIDENCE.fields_by_name['destination_not_working'].message_type = _POLICYTOPICEVIDENCE_DESTINATIONNOTWORKING
_POLICYTOPICEVIDENCE.oneofs_by_name['value'].fields.append(
  _POLICYTOPICEVIDENCE.fields_by_name['http_code'])
_POLICYTOPICEVIDENCE.fields_by_name['http_code'].containing_oneof = _POLICYTOPICEVIDENCE.oneofs_by_name['value']
_POLICYTOPICEVIDENCE.oneofs_by_name['value'].fields.append(
  _POLICYTOPICEVIDENCE.fields_by_name['website_list'])
_POLICYTOPICEVIDENCE.fields_by_name['website_list'].containing_oneof = _POLICYTOPICEVIDENCE.oneofs_by_name['value']
_POLICYTOPICEVIDENCE.oneofs_by_name['value'].fields.append(
  _POLICYTOPICEVIDENCE.fields_by_name['text_list'])
_POLICYTOPICEVIDENCE.fields_by_name['text_list'].containing_oneof = _POLICYTOPICEVIDENCE.oneofs_by_name['value']
_POLICYTOPICEVIDENCE.oneofs_by_name['value'].fields.append(
  _POLICYTOPICEVIDENCE.fields_by_name['language_code'])
_POLICYTOPICEVIDENCE.fields_by_name['language_code'].containing_oneof = _POLICYTOPICEVIDENCE.oneofs_by_name['value']
_POLICYTOPICEVIDENCE.oneofs_by_name['value'].fields.append(
  _POLICYTOPICEVIDENCE.fields_by_name['destination_text_list'])
_POLICYTOPICEVIDENCE.fields_by_name['destination_text_list'].containing_oneof = _POLICYTOPICEVIDENCE.oneofs_by_name['value']
_POLICYTOPICEVIDENCE.oneofs_by_name['value'].fields.append(
  _POLICYTOPICEVIDENCE.fields_by_name['destination_mismatch'])
_POLICYTOPICEVIDENCE.fields_by_name['destination_mismatch'].containing_oneof = _POLICYTOPICEVIDENCE.oneofs_by_name['value']
_POLICYTOPICEVIDENCE.oneofs_by_name['value'].fields.append(
  _POLICYTOPICEVIDENCE.fields_by_name['destination_not_working'])
_POLICYTOPICEVIDENCE.fields_by_name['destination_not_working'].containing_oneof = _POLICYTOPICEVIDENCE.oneofs_by_name['value']
_POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINTLIST.fields_by_name['total_targeted_countries'].message_type = google_dot_protobuf_dot_wrappers__pb2._INT32VALUE
_POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINTLIST.fields_by_name['countries'].message_type = _POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINT
_POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINTLIST.containing_type = _POLICYTOPICCONSTRAINT
_POLICYTOPICCONSTRAINT_RESELLERCONSTRAINT.containing_type = _POLICYTOPICCONSTRAINT
_POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINT.fields_by_name['country_criterion'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINT.containing_type = _POLICYTOPICCONSTRAINT
_POLICYTOPICCONSTRAINT.fields_by_name['country_constraint_list'].message_type = _POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINTLIST
_POLICYTOPICCONSTRAINT.fields_by_name['reseller_constraint'].message_type = _POLICYTOPICCONSTRAINT_RESELLERCONSTRAINT
_POLICYTOPICCONSTRAINT.fields_by_name['certificate_missing_in_country_list'].message_type = _POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINTLIST
_POLICYTOPICCONSTRAINT.fields_by_name['certificate_domain_mismatch_in_country_list'].message_type = _POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINTLIST
_POLICYTOPICCONSTRAINT.oneofs_by_name['value'].fields.append(
  _POLICYTOPICCONSTRAINT.fields_by_name['country_constraint_list'])
_POLICYTOPICCONSTRAINT.fields_by_name['country_constraint_list'].containing_oneof = _POLICYTOPICCONSTRAINT.oneofs_by_name['value']
_POLICYTOPICCONSTRAINT.oneofs_by_name['value'].fields.append(
  _POLICYTOPICCONSTRAINT.fields_by_name['reseller_constraint'])
_POLICYTOPICCONSTRAINT.fields_by_name['reseller_constraint'].containing_oneof = _POLICYTOPICCONSTRAINT.oneofs_by_name['value']
_POLICYTOPICCONSTRAINT.oneofs_by_name['value'].fields.append(
  _POLICYTOPICCONSTRAINT.fields_by_name['certificate_missing_in_country_list'])
_POLICYTOPICCONSTRAINT.fields_by_name['certificate_missing_in_country_list'].containing_oneof = _POLICYTOPICCONSTRAINT.oneofs_by_name['value']
_POLICYTOPICCONSTRAINT.oneofs_by_name['value'].fields.append(
  _POLICYTOPICCONSTRAINT.fields_by_name['certificate_domain_mismatch_in_country_list'])
_POLICYTOPICCONSTRAINT.fields_by_name['certificate_domain_mismatch_in_country_list'].containing_oneof = _POLICYTOPICCONSTRAINT.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['PolicyViolationKey'] = _POLICYVIOLATIONKEY
DESCRIPTOR.message_types_by_name['PolicyValidationParameter'] = _POLICYVALIDATIONPARAMETER
DESCRIPTOR.message_types_by_name['PolicyTopicEntry'] = _POLICYTOPICENTRY
DESCRIPTOR.message_types_by_name['PolicyTopicEvidence'] = _POLICYTOPICEVIDENCE
DESCRIPTOR.message_types_by_name['PolicyTopicConstraint'] = _POLICYTOPICCONSTRAINT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PolicyViolationKey = _reflection.GeneratedProtocolMessageType('PolicyViolationKey', (_message.Message,), dict(
  DESCRIPTOR = _POLICYVIOLATIONKEY,
  __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
  ,
  __doc__ = """Key of the violation. The key is used for referring to a violation when
  filing an exemption request.
  
  
  Attributes:
      policy_name:
          Unique ID of the violated policy.
      violating_text:
          The text that violates the policy if specified. Otherwise,
          refers to the policy in general (e.g., when requesting to be
          exempt from the whole policy). If not specified for criterion
          exemptions, the whole policy is implied. Must be specified for
          ad exemptions.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyViolationKey)
  ))
_sym_db.RegisterMessage(PolicyViolationKey)

PolicyValidationParameter = _reflection.GeneratedProtocolMessageType('PolicyValidationParameter', (_message.Message,), dict(
  DESCRIPTOR = _POLICYVALIDATIONPARAMETER,
  __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
  ,
  __doc__ = """Parameter for controlling how policy exemption is done. Ignorable policy
  topics are only usable with expanded text ads and responsive search ads.
  All other ad types must use policy violation keys.
  
  
  Attributes:
      ignorable_policy_topics:
          The list of policy topics that should not cause a
          PolicyFindingError to be reported. This field is currently
          only compatible with Enhanced Text Ad. It corresponds to the
          PolicyTopicEntry.topic field.  Resources violating these
          policies will be saved, but will not be eligible to serve.
          They may begin serving at a later time due to a change in
          policies, re-review of the resource, or a change in advertiser
          certificates.
      exempt_policy_violation_keys:
          The list of policy violation keys that should not cause a
          PolicyViolationError to be reported. Not all policy violations
          are exemptable, please refer to the is\_exemptible field in
          the returned PolicyViolationError.  Resources violating these
          polices will be saved, but will not be eligible to serve. They
          may begin serving at a later time due to a change in policies,
          re-review of the resource, or a change in advertiser
          certificates.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyValidationParameter)
  ))
_sym_db.RegisterMessage(PolicyValidationParameter)

PolicyTopicEntry = _reflection.GeneratedProtocolMessageType('PolicyTopicEntry', (_message.Message,), dict(
  DESCRIPTOR = _POLICYTOPICENTRY,
  __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
  ,
  __doc__ = """Policy finding attached to a resource (e.g. alcohol policy associated
  with a site that sells alcohol).
  
  Each PolicyTopicEntry has a topic that indicates the specific ads policy
  the entry is about and a type to indicate the effect that the entry will
  have on serving. It may optionally have one or more evidences that
  indicate the reason for the finding. It may also optionally have one or
  more constraints that provide details about how serving may be
  restricted.
  
  
  Attributes:
      topic:
          Policy topic this finding refers to. For example, "ALCOHOL",
          "TRADEMARKS\_IN\_AD\_TEXT", or "DESTINATION\_NOT\_WORKING".
          The set of possible policy topics is not fixed for a
          particular API version and may change at any time.
      type:
          Describes the negative or positive effect this policy will
          have on serving.
      evidences:
          Additional information that explains policy finding (e.g. the
          brand name for a trademark finding).
      constraints:
          Indicates how serving of this resource may be affected (e.g.
          not serving in a country).
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyTopicEntry)
  ))
_sym_db.RegisterMessage(PolicyTopicEntry)

PolicyTopicEvidence = _reflection.GeneratedProtocolMessageType('PolicyTopicEvidence', (_message.Message,), dict(

  TextList = _reflection.GeneratedProtocolMessageType('TextList', (_message.Message,), dict(
    DESCRIPTOR = _POLICYTOPICEVIDENCE_TEXTLIST,
    __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
    ,
    __doc__ = """A list of fragments of text that violated a policy.
    
    
    Attributes:
        texts:
            The fragments of text from the resource that caused the policy
            finding.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyTopicEvidence.TextList)
    ))
  ,

  WebsiteList = _reflection.GeneratedProtocolMessageType('WebsiteList', (_message.Message,), dict(
    DESCRIPTOR = _POLICYTOPICEVIDENCE_WEBSITELIST,
    __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
    ,
    __doc__ = """A list of websites that caused a policy finding. Used for
    ONE\_WEBSITE\_PER\_AD\_GROUP policy topic, for example. In case there
    are more than five websites, only the top five (those that appear in
    resources the most) will be listed here.
    
    
    Attributes:
        websites:
            Websites that caused the policy finding.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyTopicEvidence.WebsiteList)
    ))
  ,

  DestinationTextList = _reflection.GeneratedProtocolMessageType('DestinationTextList', (_message.Message,), dict(
    DESCRIPTOR = _POLICYTOPICEVIDENCE_DESTINATIONTEXTLIST,
    __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
    ,
    __doc__ = """A list of strings found in a destination page that caused a policy
    finding.
    
    
    Attributes:
        destination_texts:
            List of text found in the resource's destination page.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationTextList)
    ))
  ,

  DestinationMismatch = _reflection.GeneratedProtocolMessageType('DestinationMismatch', (_message.Message,), dict(
    DESCRIPTOR = _POLICYTOPICEVIDENCE_DESTINATIONMISMATCH,
    __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
    ,
    __doc__ = """Evidence of mismatches between the URLs of a resource.
    
    
    Attributes:
        url_types:
            The set of URLs that did not match each other.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationMismatch)
    ))
  ,

  DestinationNotWorking = _reflection.GeneratedProtocolMessageType('DestinationNotWorking', (_message.Message,), dict(
    DESCRIPTOR = _POLICYTOPICEVIDENCE_DESTINATIONNOTWORKING,
    __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
    ,
    __doc__ = """Evidence details when the destination is returning an HTTP error code or
    isn't functional in all locations for commonly used devices.
    
    
    Attributes:
        expanded_url:
            The full URL that didn't work.
        device:
            The type of device that failed to load the URL.
        last_checked_date_time:
            The time the URL was last checked. The format is "YYYY-MM-DD
            HH:MM:SS". Examples: "2018-03-05 09:15:00" or "2018-02-01
            14:34:30"
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyTopicEvidence.DestinationNotWorking)
    ))
  ,
  DESCRIPTOR = _POLICYTOPICEVIDENCE,
  __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
  ,
  __doc__ = """Additional information that explains a policy finding.
  
  
  Attributes:
      value:
          Specific evidence information depending on the evidence type.
      http_code:
          HTTP code returned when the final URL was crawled.
      website_list:
          List of websites linked with this resource.
      text_list:
          List of evidence found in the text of a resource.
      language_code:
          The language the resource was detected to be written in. This
          is an IETF language tag such as "en-US".
      destination_text_list:
          The text in the destination of the resource that is causing a
          policy finding.
      destination_mismatch:
          Mismatch between the destinations of a resource's URLs.
      destination_not_working:
          Details when the destination is returning an HTTP error code
          or isn't functional in all locations for commonly used
          devices.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyTopicEvidence)
  ))
_sym_db.RegisterMessage(PolicyTopicEvidence)
_sym_db.RegisterMessage(PolicyTopicEvidence.TextList)
_sym_db.RegisterMessage(PolicyTopicEvidence.WebsiteList)
_sym_db.RegisterMessage(PolicyTopicEvidence.DestinationTextList)
_sym_db.RegisterMessage(PolicyTopicEvidence.DestinationMismatch)
_sym_db.RegisterMessage(PolicyTopicEvidence.DestinationNotWorking)

PolicyTopicConstraint = _reflection.GeneratedProtocolMessageType('PolicyTopicConstraint', (_message.Message,), dict(

  CountryConstraintList = _reflection.GeneratedProtocolMessageType('CountryConstraintList', (_message.Message,), dict(
    DESCRIPTOR = _POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINTLIST,
    __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
    ,
    __doc__ = """A list of countries where a resource's serving is constrained.
    
    
    Attributes:
        total_targeted_countries:
            Total number of countries targeted by the resource.
        countries:
            Countries in which serving is restricted.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyTopicConstraint.CountryConstraintList)
    ))
  ,

  ResellerConstraint = _reflection.GeneratedProtocolMessageType('ResellerConstraint', (_message.Message,), dict(
    DESCRIPTOR = _POLICYTOPICCONSTRAINT_RESELLERCONSTRAINT,
    __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
    ,
    __doc__ = """Indicates that a policy topic was constrained due to disapproval of the
    website for reseller purposes.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyTopicConstraint.ResellerConstraint)
    ))
  ,

  CountryConstraint = _reflection.GeneratedProtocolMessageType('CountryConstraint', (_message.Message,), dict(
    DESCRIPTOR = _POLICYTOPICCONSTRAINT_COUNTRYCONSTRAINT,
    __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
    ,
    __doc__ = """Indicates that a resource's ability to serve in a particular country is
    constrained.
    
    
    Attributes:
        country_criterion:
            Geo target constant resource name of the country in which
            serving is constrained.
    """,
    # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyTopicConstraint.CountryConstraint)
    ))
  ,
  DESCRIPTOR = _POLICYTOPICCONSTRAINT,
  __module__ = 'google.ads.googleads_v1.proto.common.policy_pb2'
  ,
  __doc__ = """Describes the effect on serving that a policy topic entry will have.
  
  
  Attributes:
      value:
          Specific information about the constraint.
      country_constraint_list:
          Countries where the resource cannot serve.
      reseller_constraint:
          Reseller constraint.
      certificate_missing_in_country_list:
          Countries where a certificate is required for serving.
      certificate_domain_mismatch_in_country_list:
          Countries where the resource's domain is not covered by the
          certificates associated with it.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.common.PolicyTopicConstraint)
  ))
_sym_db.RegisterMessage(PolicyTopicConstraint)
_sym_db.RegisterMessage(PolicyTopicConstraint.CountryConstraintList)
_sym_db.RegisterMessage(PolicyTopicConstraint.ResellerConstraint)
_sym_db.RegisterMessage(PolicyTopicConstraint.CountryConstraint)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/enums/interaction_type.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/enums/interaction_type.proto',
  package='google.ads.googleads.v1.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v1.enumsB\024InteractionTypeProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V1.Enums\312\002\035Google\\Ads\\GoogleAds\\V1\\Enums\352\002!Google::Ads::GoogleAds::V1::Enums'),
  serialized_pb=_b('\n:google/ads/googleads_v1/proto/enums/interaction_type.proto\x12\x1dgoogle.ads.googleads.v1.enums\x1a\x1cgoogle/api/annotations.proto\"R\n\x13InteractionTypeEnum\";\n\x0fInteractionType\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\n\n\x05\x43\x41LLS\x10\xc0>B\xe9\x01\n!com.google.ads.googleads.v1.enumsB\x14InteractionTypeProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v1/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V1.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V1\\Enums\xea\x02!Google::Ads::GoogleAds::V1::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_INTERACTIONTYPEENUM_INTERACTIONTYPE = _descriptor.EnumDescriptor(
  name='InteractionType',
  full_name='google.ads.googleads.v1.enums.InteractionTypeEnum.InteractionType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CALLS', index=2, number=8000,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=146,
  serialized_end=205,
)
_sym_db.RegisterEnumDescriptor(_INTERACTIONTYPEENUM_INTERACTIONTYPE)


_INTERACTIONTYPEENUM = _descriptor.Descriptor(
  name='InteractionTypeEnum',
  full_name='google.ads.googleads.v1.enums.InteractionTypeEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _INTERACTIONTYPEENUM_INTERACTIONTYPE,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=205,
)

_INTERACTIONTYPEENUM_INTERACTIONTYPE.containing_type = _INTERACTIONTYPEENUM
DESCRIPTOR.message_types_by_name['InteractionTypeEnum'] = _INTERACTIONTYPEENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

InteractionTypeEnum = _reflection.GeneratedProtocolMessageType('InteractionTypeEnum', (_message.Message,), dict(
  DESCRIPTOR = _INTERACTIONTYPEENUM,
  __module__ = 'google.ads.googleads_v1.proto.enums.interaction_type_pb2'
  ,
  __doc__ = """Container for enum describing possible interaction types.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.enums.InteractionTypeEnum)
  ))
_sym_db.RegisterMessage(InteractionTypeEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/billing_setup_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/billing_setup_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\026BillingSetupErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n>google/ads/googleads_v1/proto/errors/billing_setup_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xfb\x04\n\x15\x42illingSetupErrorEnum\"\xe1\x04\n\x11\x42illingSetupError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\'\n#CANNOT_USE_EXISTING_AND_NEW_ACCOUNT\x10\x02\x12\'\n#CANNOT_REMOVE_STARTED_BILLING_SETUP\x10\x03\x12\x32\n.CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT\x10\x04\x12\x33\n/BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS\x10\x05\x12\x1c\n\x18INVALID_PAYMENTS_ACCOUNT\x10\x06\x12\x35\n1BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY\x10\x07\x12\x1b\n\x17INVALID_START_TIME_TYPE\x10\x08\x12#\n\x1fTHIRD_PARTY_ALREADY_HAS_BILLING\x10\t\x12\x1d\n\x19\x42ILLING_SETUP_IN_PROGRESS\x10\n\x12\x18\n\x14NO_SIGNUP_PERMISSION\x10\x0b\x12!\n\x1d\x43HANGE_OF_BILL_TO_IN_PROGRESS\x10\x0c\x12\x1e\n\x1aPAYMENTS_PROFILE_NOT_FOUND\x10\r\x12\x1e\n\x1aPAYMENTS_ACCOUNT_NOT_FOUND\x10\x0e\x12\x1f\n\x1bPAYMENTS_PROFILE_INELIGIBLE\x10\x0f\x12\x1f\n\x1bPAYMENTS_ACCOUNT_INELIGIBLE\x10\x10\x42\xf1\x01\n\"com.google.ads.googleads.v1.errorsB\x16\x42illingSetupErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_BILLINGSETUPERRORENUM_BILLINGSETUPERROR = _descriptor.EnumDescriptor(
  name='BillingSetupError',
  full_name='google.ads.googleads.v1.errors.BillingSetupErrorEnum.BillingSetupError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_USE_EXISTING_AND_NEW_ACCOUNT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_REMOVE_STARTED_BILLING_SETUP', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_CHANGE_BILLING_TO_SAME_PAYMENTS_ACCOUNT', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_STATUS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PAYMENTS_ACCOUNT', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BILLING_SETUP_NOT_PERMITTED_FOR_CUSTOMER_CATEGORY', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_START_TIME_TYPE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='THIRD_PARTY_ALREADY_HAS_BILLING', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BILLING_SETUP_IN_PROGRESS', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_SIGNUP_PERMISSION', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CHANGE_OF_BILL_TO_IN_PROGRESS', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAYMENTS_PROFILE_NOT_FOUND', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAYMENTS_ACCOUNT_NOT_FOUND', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAYMENTS_PROFILE_INELIGIBLE', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='PAYMENTS_ACCOUNT_INELIGIBLE', index=16, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=155,
  serialized_end=764,
)
_sym_db.RegisterEnumDescriptor(_BILLINGSETUPERRORENUM_BILLINGSETUPERROR)


_BILLINGSETUPERRORENUM = _descriptor.Descriptor(
  name='BillingSetupErrorEnum',
  full_name='google.ads.googleads.v1.errors.BillingSetupErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _BILLINGSETUPERRORENUM_BILLINGSETUPERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=129,
  serialized_end=764,
)

_BILLINGSETUPERRORENUM_BILLINGSETUPERROR.containing_type = _BILLINGSETUPERRORENUM
DESCRIPTOR.message_types_by_name['BillingSetupErrorEnum'] = _BILLINGSETUPERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

BillingSetupErrorEnum = _reflection.GeneratedProtocolMessageType('BillingSetupErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _BILLINGSETUPERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.billing_setup_error_pb2'
  ,
  __doc__ = """Container for enum describing possible billing setup errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.BillingSetupErrorEnum)
  ))
_sym_db.RegisterMessage(BillingSetupErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/feed_mapping_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/feed_mapping_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\025FeedMappingErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n=google/ads/googleads_v1/proto/errors/feed_mapping_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xe7\x05\n\x14\x46\x65\x65\x64MappingErrorEnum\"\xce\x05\n\x10\x46\x65\x65\x64MappingError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1d\n\x19INVALID_PLACEHOLDER_FIELD\x10\x02\x12\x1b\n\x17INVALID_CRITERION_FIELD\x10\x03\x12\x1c\n\x18INVALID_PLACEHOLDER_TYPE\x10\x04\x12\x1a\n\x16INVALID_CRITERION_TYPE\x10\x05\x12\x1f\n\x1bNO_ATTRIBUTE_FIELD_MAPPINGS\x10\x07\x12 \n\x1c\x46\x45\x45\x44_ATTRIBUTE_TYPE_MISMATCH\x10\x08\x12\x38\n4CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED\x10\t\x12*\n&MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE\x10\n\x12(\n$MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE\x10\x0b\x12+\n\'MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD\x10\x0c\x12)\n%MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD\x10\r\x12\'\n#UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS\x10\x0e\x12.\n*LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS\x10\x0f\x12)\n%CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED\x10\x10\x12:\n6INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED\x10\x11\x12;\n7INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE\x10\x12\x42\xf0\x01\n\"com.google.ads.googleads.v1.errorsB\x15\x46\x65\x65\x64MappingErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_FEEDMAPPINGERRORENUM_FEEDMAPPINGERROR = _descriptor.EnumDescriptor(
  name='FeedMappingError',
  full_name='google.ads.googleads.v1.errors.FeedMappingErrorEnum.FeedMappingError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PLACEHOLDER_FIELD', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CRITERION_FIELD', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PLACEHOLDER_TYPE', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_CRITERION_TYPE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='NO_ATTRIBUTE_FIELD_MAPPINGS', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='FEED_ATTRIBUTE_TYPE_MISMATCH', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED', index=15, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE', index=17, number=18,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=153,
  serialized_end=871,
)
_sym_db.RegisterEnumDescriptor(_FEEDMAPPINGERRORENUM_FEEDMAPPINGERROR)


_FEEDMAPPINGERRORENUM = _descriptor.Descriptor(
  name='FeedMappingErrorEnum',
  full_name='google.ads.googleads.v1.errors.FeedMappingErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _FEEDMAPPINGERRORENUM_FEEDMAPPINGERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=871,
)

_FEEDMAPPINGERRORENUM_FEEDMAPPINGERROR.containing_type = _FEEDMAPPINGERRORENUM
DESCRIPTOR.message_types_by_name['FeedMappingErrorEnum'] = _FEEDMAPPINGERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

FeedMappingErrorEnum = _reflection.GeneratedProtocolMessageType('FeedMappingErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _FEEDMAPPINGERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.feed_mapping_error_pb2'
  ,
  __doc__ = """Container for enum describing possible feed item errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.FeedMappingErrorEnum)
  ))
_sym_db.RegisterMessage(FeedMappingErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)
